@@ -40,6 +40,21 @@ static gchar *toolbar_type_label[NUM_TOOLBAR_TYPES] = {
     N_ ("Both")
 };
 
+/* Variables used in the selection of the presume protocol */
+#define NUM_PRESUME_PROTOCOLS 3
+
+static Protocol presume_protocol[NUM_PRESUME_PROTOCOLS] = {
+    PROTOCOL_NONE,
+    PROTOCOL_HTTP,
+    PROTOCOL_FTP
+};
+
+static gchar *presume_protocol_label[NUM_PRESUME_PROTOCOLS] = {
+    N_ ("None"),
+    N_ ("HTTP"),
+    N_ ("FTP")
+};
+
 
 /* Structure that keeps the widgets containing the current preferences */
 typedef struct 
@@ -72,6 +87,7 @@ typedef struct
     GtkWidget *use_beep;                        /* Toggle button */
     GtkWidget *dir_list;                        /* CList */
     GtkWidget *stop_dl_on_link_loss;            /* Toggle button */
+    GtkWidget *presume_protocol[NUM_PRESUME_PROTOCOLS]; /* Toggle button */
 } PrefDialogData;
 
 
@@ -136,6 +152,8 @@ apply_prefs_auto (PrefDialogData *pref)
 static void
 apply_prefs_download (PrefDialogData *pref)
 {
+    guint i;
+
     /* Default download directory */
     gtm_pref.def_download_dir = 
         g_strdup (gtk_entry_get_text (GTK_ENTRY (
@@ -157,6 +175,16 @@ apply_prefs_download (PrefDialogData *pref)
         GTK_TOGGLE_BUTTON (pref->use_passive_ftp));
     gnome_config_set_bool ("use_passive_ftp",
                            gtm_pref.use_passive_ftp);
+
+    /* Presume protocol */
+    for (i = 0; i < NUM_PRESUME_PROTOCOLS; i++) {
+        if (gtk_toggle_button_get_active (
+            GTK_TOGGLE_BUTTON (pref->presume_protocol[i]))) {
+            gtm_pref.presume_protocol = presume_protocol[i];
+            break;
+        }
+    }
+    gnome_config_set_int ("presume_protocol", gtm_pref.presume_protocol);
 }
 
 static void
@@ -525,6 +553,7 @@ create_download_page (PrefDialogData *pref)
     GtkWidget *def_download_dir;
     GtkObject *adjustment;
     GSList *group;
+    guint i;
 
     /* Create vbox for page lines */
     vbox = gtk_vbox_new (FALSE, GNOME_PAD_SMALL);
@@ -567,6 +596,23 @@ create_download_page (PrefDialogData *pref)
     gtk_box_pack_start (GTK_BOX (vbox), pref->use_passive_ftp, FALSE, FALSE,
                         0);
 
+    /* Toolbar style */
+    hbox = gtk_hbox_new (FALSE, GNOME_PAD_SMALL);
+    gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
+    label = gtk_label_new (_ ("Presume Protocol:"));
+    gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
+    group = NULL;
+    for (i = 0; i < NUM_PRESUME_PROTOCOLS; i++) {
+        pref->presume_protocol[i] = 
+            gtk_radio_button_new_with_label (group,
+                                             _ (presume_protocol_label[i]));
+        gtk_box_pack_start (GTK_BOX (hbox), pref->presume_protocol[i], FALSE, 
+                            FALSE, 0);
+        group = 
+            gtk_radio_button_group (GTK_RADIO_BUTTON (
+                pref->presume_protocol[i]));
+    }
+
     /* Set current preferences */
     gtk_entry_set_text (GTK_ENTRY (pref->def_download_dir), 
                         gtm_pref.def_download_dir);
@@ -581,6 +627,13 @@ create_download_page (PrefDialogData *pref)
         gtk_spin_button_set_value (GTK_SPIN_BUTTON (pref->num_retries),
                                    (gfloat) gtm_pref.num_retries);
     }
+    for (i = 0; i < NUM_PRESUME_PROTOCOLS; i++) {
+        if (gtm_pref.presume_protocol == presume_protocol[i]) {
+            gtk_toggle_button_set_active (
+                GTK_TOGGLE_BUTTON (pref->presume_protocol[i]), TRUE);
+            break;
+        }
+    }
 
     /* Connect the signal that acknowledges the change on the widget to 
      * function that turns on the OK and APPLY buttons */
@@ -599,6 +652,10 @@ create_download_page (PrefDialogData *pref)
     gtk_signal_connect (GTK_OBJECT (pref->num_retries), "changed",
                         GTK_SIGNAL_FUNC (pref_modified_cb),
                         (gpointer) pref);
+    for (i = 0; i < NUM_PRESUME_PROTOCOLS; i++)
+        gtk_signal_connect (GTK_OBJECT (pref->presume_protocol[i]), "clicked",
+                            GTK_SIGNAL_FUNC (pref_modified_cb),
+                            (gpointer) pref);
 
     return vbox;
 }
