@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 1999, 2000 Bruno Pires Marinho
+ *  Copyright (C) 1999-2001 Bruno Pires Marinho
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -40,8 +40,8 @@ typedef struct
     GtkWidget *sess_time;        /* Label */
     GtkWidget *sess_speed;       /* Label */
     GtkWidget *local_dir;        /* Label */
-    GtkWidget *disable_proxy;    /* Toggle Button */
-    GtkWidget *disable_auto_dl;  /* Toggle Button */
+    GtkWidget *use_proxy;        /* Toggle Button */
+    GtkWidget *use_auto_dl;      /* Toggle Button */
 } Info;
 
 static Info info;
@@ -233,9 +233,9 @@ toggle_proxy_cb (GtkWidget *widget, gpointer data)
 
     file_data = gtk_clist_get_row_data (GTK_CLIST (dl_file_list),
                                         GTK_CLIST (dl_file_list)->focus_row);
-    file_data_set_disable_proxy (file_data,
-                                 gtk_toggle_button_get_active (
-                                     GTK_TOGGLE_BUTTON (info.disable_proxy)));
+    file_data_set_use_proxy (file_data,
+                             gtk_toggle_button_get_active (
+                                 GTK_TOGGLE_BUTTON (info.use_proxy)));
     download_info_update (file_data);
     dialog_prop (FALSE, file_data);
 }
@@ -247,10 +247,10 @@ toggle_auto_dl_cb (GtkWidget *widget, gpointer data)
 
     file_data = gtk_clist_get_row_data (GTK_CLIST (dl_file_list),
                                         GTK_CLIST (dl_file_list)->focus_row);
-    file_data_set_disable_auto_dl (file_data,
+    file_data_set_use_auto_dl (file_data,
                                    gtk_toggle_button_get_active (
                                        GTK_TOGGLE_BUTTON (
-                                           info.disable_auto_dl)));
+                                           info.use_auto_dl)));
     download_info_update (file_data);
     dialog_prop (FALSE, file_data);
 }
@@ -282,17 +282,17 @@ create_frame_options (void)
     gtk_misc_set_alignment (GTK_MISC (info.local_dir), 1.0, 0.5);
     gtk_table_attach_defaults (GTK_TABLE (table), info.local_dir, 1, 2, 0, 1);
 
-    info.disable_proxy = gtk_check_button_new_with_label (_ ("Disable proxy"));
-    gtk_table_attach_defaults (GTK_TABLE (table), info.disable_proxy,
+    info.use_proxy = gtk_check_button_new_with_label (_ ("Use proxy"));
+    gtk_table_attach_defaults (GTK_TABLE (table), info.use_proxy,
                                0, 2, 1, 2);
-    gtk_signal_connect (GTK_OBJECT (info.disable_proxy), "toggled", 
+    gtk_signal_connect (GTK_OBJECT (info.use_proxy), "toggled", 
                         GTK_SIGNAL_FUNC (toggle_proxy_cb), NULL);
 
-    info.disable_auto_dl =
-        gtk_check_button_new_with_label (_ ("Disable auto download"));
-    gtk_table_attach_defaults (GTK_TABLE (table), info.disable_auto_dl,
+    info.use_auto_dl =
+        gtk_check_button_new_with_label (_ ("Use auto download"));
+    gtk_table_attach_defaults (GTK_TABLE (table), info.use_auto_dl,
                                0, 2, 2, 3);
-    gtk_signal_connect (GTK_OBJECT (info.disable_auto_dl), "toggled", 
+    gtk_signal_connect (GTK_OBJECT (info.use_auto_dl), "toggled", 
                         GTK_SIGNAL_FUNC (toggle_auto_dl_cb), NULL);
 
     return frame;
@@ -355,7 +355,7 @@ download_info_update_total_size (FileData *file_data)
     else if (file_data->total_size == 0)
 	strcpy (buffer, _ ("Unspecified"));
     else
-	sprintf (buffer, "%d kb", (file_data->total_size + 512) / 1024);
+	sprintf (buffer, "%d kB", (file_data->total_size + 512) / 1024);
     gtk_label_set_text (GTK_LABEL (info.size), buffer);
 
     if (file_data->state != DL_NOT_STARTED) {
@@ -381,7 +381,7 @@ download_info_update_statistics (FileData *file_data)
     if (file_data->state == DL_NOT_STARTED || file_data->state == DL_COMPLETED)
         strcpy (buffer, "");
     else
-        sprintf (buffer, "%d kb", (file_data->cur_size + 512) / 1024);
+        sprintf (buffer, "%d kB", (file_data->cur_size + 512) / 1024);
     gtk_label_set_text (GTK_LABEL (info.retrieved), buffer);
     if (file_data->state == DL_COMPLETED)
         gtk_progress_set_percentage (GTK_PROGRESS (info.retr_progress), 1.0);
@@ -449,13 +449,13 @@ download_info_update_statistics (FileData *file_data)
     if (file_data->total_time != 0) {
         if (file_data->state == DL_COMPLETED) {
             if (file_data->total_size != 0)
-                sprintf (buffer, "%.2f kb/s", 
+                sprintf (buffer, "%.2f kB/s", 
                          ((gfloat) file_data->total_size
                                    / file_data->total_time) / 1024);
             else
                 strcpy (buffer, "");
         } else if (file_data->cur_size != 0)
-            sprintf (buffer, "%.2f kb/s", 
+            sprintf (buffer, "%.2f kB/s", 
                      ((gfloat) file_data->cur_size / file_data->total_time)
                               / 1024);
         else
@@ -470,7 +470,7 @@ download_info_update_statistics (FileData *file_data)
             if (retr_size == 0)
                 strcpy (buffer, _ ("staled"));
             else
-                sprintf (buffer, "%.2f kb/s",
+                sprintf (buffer, "%.2f kB/s",
                          ((gfloat) retr_size / file_data->session_elapsed) 
                           / 1024);
         }
@@ -500,8 +500,8 @@ download_info_update (FileData *file_data)
 	gtk_label_set_text (GTK_LABEL (info.sess_time), "");
 	gtk_label_set_text (GTK_LABEL (info.sess_speed), "");
 	gtk_label_set_text (GTK_LABEL (info.local_dir), "");
-        gtk_widget_set_sensitive (GTK_WIDGET (info.disable_auto_dl), FALSE);
-        gtk_widget_set_sensitive (GTK_WIDGET (info.disable_proxy), FALSE);
+        gtk_widget_set_sensitive (GTK_WIDGET (info.use_auto_dl), FALSE);
+        gtk_widget_set_sensitive (GTK_WIDGET (info.use_proxy), FALSE);
     } else {
         /* Update state, total size and statistics */
         download_info_update_state (file_data);
@@ -514,14 +514,14 @@ download_info_update (FileData *file_data)
 
 	/* Update options */
 	gtk_label_set_text (GTK_LABEL (info.local_dir), file_data->dir);
-        gtk_widget_set_sensitive (GTK_WIDGET (info.disable_auto_dl), TRUE);
-        gtk_widget_set_sensitive (GTK_WIDGET (info.disable_proxy), TRUE);
+        gtk_widget_set_sensitive (GTK_WIDGET (info.use_auto_dl), TRUE);
+        gtk_widget_set_sensitive (GTK_WIDGET (info.use_proxy), TRUE);
         gtk_toggle_button_set_active 
-            (GTK_TOGGLE_BUTTON (info.disable_auto_dl),
-             file_data->disable_auto_dl);
+            (GTK_TOGGLE_BUTTON (info.use_auto_dl),
+             file_data->use_auto_dl);
         gtk_toggle_button_set_active 
-            (GTK_TOGGLE_BUTTON (info.disable_proxy),
-             file_data->disable_proxy);
+            (GTK_TOGGLE_BUTTON (info.use_proxy),
+             file_data->use_proxy);
 
         /* Update the state of the toggle auto download button on the toolbar
            and menu */
