@@ -94,7 +94,7 @@ file_data_free (FileData *file_data)
             g_free (files[i]);
         g_free (files);
         path = g_strdup_printf ("/gtm/File%d/", file_data->id);
-        gnome_config_clean_section (path);
+	gnome_config_clean_section (path);
         gnome_config_sync ();
         g_free (path);
 	g_free (file_data->url);
@@ -107,7 +107,7 @@ file_data_free (FileData *file_data)
 }
 
 void
-file_data_set_state (FileData *file_data, DlState state)
+file_data_set_state (FileData *file_data, DlState state, gboolean sync)
 {
     gint row;
     gchar *path;
@@ -120,7 +120,8 @@ file_data_set_state (FileData *file_data, DlState state)
         || state == DL_COMPLETED) {
         path = g_strdup_printf ("/gtm/File%d/state", file_data->id);
         gnome_config_set_int (path, file_data->state);
-        gnome_config_sync ();
+	if (sync)
+            gnome_config_sync ();
         g_free (path);
     }
     if (state == DL_COMPLETED)
@@ -139,7 +140,8 @@ file_data_set_state (FileData *file_data, DlState state)
 }
 
 void
-file_data_set_total_size (FileData *file_data, guint32 total_size)
+file_data_set_total_size (FileData *file_data, guint32 total_size,
+                          gboolean sync)
 {
     gint row;
     gchar *path;
@@ -147,7 +149,8 @@ file_data_set_total_size (FileData *file_data, guint32 total_size)
     file_data->total_size = total_size;
     path = g_strdup_printf ("/gtm/File%d/size", file_data->id);
     gnome_config_set_int (path, file_data->total_size);
-    gnome_config_sync ();
+    if (sync)
+        gnome_config_sync ();
     g_free (path);
     if (file_data->file_list != NULL) {
         row = gtk_clist_find_row_from_data (GTK_CLIST (file_data->file_list),
@@ -207,7 +210,7 @@ void file_data_set_use_auto_dl (FileData *file_data,
 }
 
 void
-file_data_update_statistics (FileData *file_data)
+file_data_update_statistics (FileData *file_data, gboolean sync)
 {
     gint row;
     guint32 cur_size;
@@ -236,7 +239,8 @@ file_data_update_statistics (FileData *file_data)
 	file_data->session_elapsed = 0;
     path = g_strdup_printf ("/gtm/File%d/time", file_data->id);
     gnome_config_set_int (path, file_data->total_time);
-    gnome_config_sync ();
+    if (sync)
+        gnome_config_sync ();
     g_free (path);
 
     if (file_data->file_list != NULL) {
@@ -273,16 +277,16 @@ file_data_process_information (FileData *file_data)
         /* Set the appropriate state after stopping */
 	if (WIFEXITED (status)) {
             if (WEXITSTATUS (status) == 0)
-                file_data_set_state (file_data, DL_COMPLETED);
+                file_data_set_state (file_data, DL_COMPLETED, TRUE);
             else if (WEXITSTATUS (status) == 255) {
                 /* Only reaches here if wget is not found */
-                file_data_set_state (file_data, DL_NOT_RUNNING);
+                file_data_set_state (file_data, DL_NOT_RUNNING, TRUE);
                 g_warning ("couldn't find program wget to exec\n");
             } else
-                file_data_set_state (file_data, DL_NOT_RUNNING);
+                file_data_set_state (file_data, DL_NOT_RUNNING, TRUE);
 	} else
-	    file_data_set_state (file_data, DL_NOT_RUNNING);
-        file_data_update_statistics (file_data);
+	    file_data_set_state (file_data, DL_NOT_RUNNING, TRUE);
+        file_data_update_statistics (file_data, TRUE);
 
         /* Decrease the number of current downloads */
         if (num_of_download > 0)
@@ -393,7 +397,7 @@ file_data_start_download (FileData *file_data)
         fcntl (file_data->log_fd, F_SETFL, O_NONBLOCK);
         file_data->line = g_new (gchar, MAX_WGET_LINE_SIZE + 1);
         file_data->line_pos = 0;
-        file_data_set_state (file_data, DL_NOT_CONNECTED);
+        file_data_set_state (file_data, DL_NOT_CONNECTED, TRUE);
         file_data->log_tag = 
             gtk_timeout_add (gtm_pref.file_list_refresh, 
                              (GtkFunction) file_data_process_information,
@@ -439,10 +443,10 @@ file_data_stop_download (FileData *file_data)
 
             /* Set the appropriate state after stopping */
             if (WIFEXITED (status) && (WEXITSTATUS (status) == 0))
-                file_data_set_state (file_data, DL_COMPLETED);
+                file_data_set_state (file_data, DL_COMPLETED, TRUE);
             else
-                file_data_set_state (file_data, DL_NOT_RUNNING);
-            file_data_update_statistics (file_data);
+                file_data_set_state (file_data, DL_NOT_RUNNING, TRUE);
+            file_data_update_statistics (file_data, TRUE);
 
             /* Decrease the number of current downloads */
             if (num_of_download > 0)
@@ -464,7 +468,7 @@ file_data_restart_download (FileData *file_data)
     /* First stop the download, clear download info and remove downloaded 
      * file */
     file_data_stop_download (file_data);
-    file_data_set_state (file_data, DL_NOT_STARTED);
+    file_data_set_state (file_data, DL_NOT_STARTED, TRUE);
     file_data->total_time = 0;
     unlink (file_data->local_filename);
 
