@@ -216,9 +216,9 @@ static void
 file_list_unselect_row (GtkCList *file_list, gint row, gint column, 
                         GdkEventButton *event, gpointer data)
 {
-    menu_toolbar_set_state (file_list);
-    menu_toolbar_set_auto_dl (file_list);
-    file_list_menu_popup_set_state (file_list);
+    //menu_toolbar_set_state (file_list);
+    //menu_toolbar_set_auto_dl (file_list);
+    //file_list_menu_popup_set_state (file_list);
     if (g_list_find (file_list->selection,
                      (gpointer) file_list->focus_row) == NULL) {
         download_info_update (NULL);
@@ -637,29 +637,99 @@ file_list_find_url (GtkCList *file_list, gchar *url)
     return -1;
 }
 
-gboolean
-file_list_add (GtkCList *file_list, FileData *file_data)
+static gboolean
+file_list_simple_add (GtkCList *file_list, FileData *file_data, 
+                      gboolean check_duplicates)
 {
     gint row;
     gchar *data[FILE_LIST_TOTAL_COLUMNS];
+    gchar *local_file;
+    GtkWidget *error;
+    FILE *fp;
 
     /* Check if the URL is not on the file list */
-    if (file_list_find_url (file_list, file_data->url) != -1)
-        return FALSE;
-    else {
-        file_data->file_list = GTK_WIDGET (file_list);
-        data[FILE_LIST_COL_STATE] = NULL;
-        data[FILE_LIST_COL_RETRIEVED] = NULL;
-        data[FILE_LIST_COL_REMAIN] = NULL;
-        data[FILE_LIST_COL_FILENAME] = file_data->filename;
-        row = gtk_clist_append (GTK_CLIST (file_list), data);
-        gtk_clist_set_row_data_full (GTK_CLIST (file_list), row, file_data,
-                                     (GtkDestroyNotify) file_data_free);
-        file_data_set_state (file_data, file_data->state);
-        file_data_set_total_size (file_data, file_data->total_size);
-        file_data_update_statistics (file_data);
-        report_event ("add");
+    if (check_duplicates &&
+        (file_list_find_url (file_list, file_data->url) != -1))
+	return FALSE;
+    /* TODO:  Error if this is startup */
+
+    /* Check if in the download directory there already is a */
+    /* file withe the same name                              */
+    local_file = g_strconcat(file_data->dir, file_data->filename, NULL);
+    fp = fopen(local_file, "r");
+    if (fp != NULL && file_data->state != DL_COMPLETED) {
+	gchar *error_msg;
+
+	fclose(fp);
+
+	error_msg = g_strconcat (_ ("File:\n"), local_file, "\n",
+				 _ ("already exist"), NULL);
+	error = gnome_message_box_new (error_msg, GNOME_MESSAGE_BOX_ERROR,
+				       GNOME_STOCK_BUTTON_OK, NULL);
+	gnome_dialog_run_and_close (GNOME_DIALOG (error));
+	g_free (error_msg);
     }
+
+    file_data->file_list = GTK_WIDGET (file_list);
+    data[FILE_LIST_COL_STATE] = NULL;
+    data[FILE_LIST_COL_RETRIEVED] = NULL;
+    data[FILE_LIST_COL_REMAIN] = NULL;
+    data[FILE_LIST_COL_FILENAME] = file_data->filename;
+    row = gtk_clist_append (GTK_CLIST (file_list), data);
+    gtk_clist_set_row_data_full (GTK_CLIST (file_list), row, file_data,
+                                 (GtkDestroyNotify) file_data_free);
+    file_data_set_state (file_data, file_data->state, FALSE);
+    file_data_set_total_size (file_data, file_data->total_size, FALSE);
+    file_data_update_statistics (file_data, FALSE);
+    return TRUE;
+}
+
+gboolean
+file_list_single_add (GtkCList *file_list, FileData *file_data)
+{
+    if (!file_list_simple_add (GTK_CLIST (file_list), file_data, TRUE))
+        return FALSE;
+
+    file_list_update_statistics (GTK_CLIST (file_list));
+    report_event ("add");
+
+    gnome_config_sync ();
+
+    return TRUE;
+}
+
+gboolean
+file_list_bulk_add (GtkCList *file_list, FileData **file_data_array,
+                    gint total_files, gboolean list_load)
+{
+    gint file_num;
+    FileData *file_data;
+
+    /* Check for duplicates, if there are any, don't add any URLs */
+    if (!list_load) {
+        for (file_num = 0; file_num < total_files; file_num++) {
+            file_data = file_data_array[file_num];
+            if (file_list_find_url (file_list, file_data->url) != -1)
+                return FALSE;
+        }
+    }
+
+    gtk_clist_freeze (GTK_CLIST (dl_file_list));
+
+    /* Add the URLs */
+    for (file_num = 0; file_num < total_files; file_num++) {
+        file_data = file_data_array[file_num];
+
+	file_list_simple_add (file_list, file_data, FALSE);
+    }
+
+    gtk_clist_thaw (GTK_CLIST (dl_file_list));
+
+    file_list_update_statistics (GTK_CLIST (file_list));
+    report_event ("add");
+
+    gnome_config_sync ();
+
     return TRUE;
 }
 
@@ -782,7 +852,7 @@ file_list_load_old_format_data (GtkCList *file_list, gint total_files)
         file_data->file_list = NULL;
         gnome_config_pop_prefix ();
         g_free (prefix);
-        file_list_add (file_list, file_data);
+        file_list_single_add (file_list, file_data);
     }
 
     /* Delete the records in old format */
@@ -827,9 +897,9 @@ file_list_load_data (GtkCList *file_list)
     gint i, j, total_files;
     gchar *prefix, *filename;
     gchar **files;
+    FileData **file_data_array;
     gboolean zero_found;
 
-    gtk_clist_freeze (file_list);
     if (gnome_config_has_section ("/gtm/FileList/")) {
 	gnome_config_push_prefix ("/gtm/FileList/");
 	if ((total_files = gnome_config_get_int ("total_files=0")) != 0) {
@@ -840,6 +910,7 @@ file_list_load_data (GtkCList *file_list)
             /* New list format */
             next_file_id = gnome_config_get_int ("next_file_id=0");
             gnome_config_get_vector ("file_ids", &total_files, &files);
+	    file_data_array = g_new (FileData *, total_files);
 
             /* Check the file_ids for errors. The errors GTM generated are a
              * repeated 0 on the list and non existing 0 section */
@@ -905,17 +976,20 @@ file_list_load_data (GtkCList *file_list)
                             gnome_config_get_int ("time=0");
                         file_data->file_list = NULL;
                         gnome_config_pop_prefix ();
-                        file_list_add (file_list, file_data);
+                        file_data_array[i] = file_data;
                     }
                     g_free (prefix);
                 }
             }
+
+            file_list_bulk_add (file_list, file_data_array, total_files, TRUE);
+
             for (i = 0; i < total_files; i++)
                 g_free (files[i]);
             g_free (files);
+            g_free (file_data_array);
         }
     }
-    gtk_clist_thaw (file_list);
 }
 
 void
