@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 1999, 2000 Bruno Pires Marinho
+ *  Copyright (C) 1999-2001 Bruno Pires Marinho
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -32,7 +32,10 @@ void file_list_set_row_statistics (GtkCList *file_list, gint row,
 
 gint file_list_find_url (GtkCList *file_list, gchar *url);
 
-gboolean file_list_add (GtkCList *file_list, FileData *file_data);
+gboolean file_list_single_add (GtkCList *file_list, FileData *file_data);
+
+gboolean file_list_bulk_add (GtkCList *file_list, FileData **file_data,
+                             gint total_files, gboolean list_load);
 
 void file_list_remove_selection (GtkCList *file_list, gboolean completed,
                                  gboolean incomplete);
