@@ -19,6 +19,12 @@
 #ifndef _GTM_H
 #define _GTM_H
 
+typedef enum {
+    PROTOCOL_NONE,
+    PROTOCOL_HTTP,
+    PROTOCOL_FTP
+} Protocol;
+
 typedef struct 
 {
     gboolean use_proxy;
@@ -46,6 +52,7 @@ typedef struct
     gboolean use_sound;
     gboolean use_beep;
     gboolean stop_dl_on_link_loss;
+    Protocol presume_protocol;
 } Preferences;
 
 /* The application used in save_state */
